@@ -20,7 +20,6 @@ use crate::storage::NodeStorage;
 use args::Args;
 use once_cell::sync::Lazy;
 use structopt::StructOpt;
-use tracing::instrument;
 
 #[cfg(feature = "metrics")]
 pub static RUNTIME: Lazy<Runtime> =
@@ -30,12 +29,23 @@ pub static RUNTIME: Lazy<Runtime> =
 #[global_allocator]
 static ALLOC: dhat::Alloc = dhat::Alloc;
 
-#[instrument]
 fn main() -> anyhow::Result<()> {
     if std::env::var("RUST_LOG").is_err() {
         std::env::set_var("RUST_LOG", "themelio_node=debug,warn");
     }
-    env_logger::Builder::from_env("RUST_LOG").init();
+    let mut builder = env_logger::Builder::from_env("RUST_LOG");
+    #[cfg(feature = "metrics")]
+    {
+        use std::io::Write;
+        builder.format(|f, r| {
+            writeln!(f, "hostname={} public_ip={} network={} region={} instance_id={} level={} message={:?}", crate::prometheus::HOSTNAME.as_str(), crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(), crate::prometheus::NETWORK.read(),
+            AWS_REGION.read(),
+               AWS_INSTANCE_ID.read(),
+            r.level(),
+            r.args())
+        });
+    }
+    builder.init();
     let opts = Args::from_args();
 
     smolscale::block_on(main_async(opts))
@@ -44,46 +54,19 @@ fn main() -> anyhow::Result<()> {
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
 
 /// Runs the main function for a node.
-#[instrument(skip(opt))]
 pub async fn main_async(opt: Args) -> anyhow::Result<()> {
     #[cfg(feature = "dhat-heap")]
     let _profiler = dhat::Profiler::new_heap();
 
-    #[cfg(not(feature = "metrics"))]
     log::info!("themelio-core v{} initializing...", VERSION);
 
-    #[cfg(feature = "metrics")]
-    log::info!(
-        "hostname={} public_ip={} network={} region={} instance_id={} themelio-core v{} initializing...",
-        crate::prometheus::HOSTNAME.as_str(),
-        crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-        crate::prometheus::NETWORK.read().expect("Could not get a read lock on NETWORK."),
-        AWS_REGION.read().expect("Could not get a read lock on AWS_REGION"),
-        AWS_INSTANCE_ID.read().expect("Could not get a read lock on AWS_INSTANCE_ID"),
-        VERSION
-    );
     let genesis = opt.genesis_config().await?;
     let netid = genesis.network;
     let storage: NodeStorage = opt.storage().await?;
     let bootstrap = opt.bootstrap().await?;
-    #[cfg(not(feature = "metrics"))]
+
     log::info!("bootstrapping with {:?}", bootstrap);
-    #[cfg(feature = "metrics")]
-    log::info!(
-        "hostname={} public_ip={} network={} region={} instance_id={} bootstrapping with {:?}",
-        crate::prometheus::HOSTNAME.as_str(),
-        crate::public_ip_address::PUBLIC_IP_ADDRESS.as_str(),
-        crate::prometheus::NETWORK
-            .read()
-            .expect("Could not get a read lock on NETWORK."),
-        AWS_REGION
-            .read()
-            .expect("Could not get a read lock on AWS_REGION"),
-        AWS_INSTANCE_ID
-            .read()
-            .expect("Could not get a read lock on AWS_INSTANCE_ID"),
-        bootstrap
-    );
+
     let _node_prot = NodeProtocol::new(
         netid,
         opt.listen_addr(),
@@ -113,13 +96,13 @@ pub async fn main_async(opt: Args) -> anyhow::Result<()> {
     };
 
     #[cfg(feature = "metrics")]
-    crate::prometheus::GLOBAL_STORAGE
-        .set(storage)
-        .ok()
-        .expect("Could not write to GLOBAL_STORAGE");
-
-    #[cfg(feature = "metrics")]
-    std::thread::spawn(|| RUNTIME.block_on(crate::prometheus::prometheus()));
+    {
+        crate::prometheus::GLOBAL_STORAGE
+            .set(storage)
+            .ok()
+            .expect("Could not write to GLOBAL_STORAGE");
+        std::thread::spawn(|| RUNTIME.block_on(crate::prometheus::prometheus()));
+    }
 
     #[cfg(feature = "dhat-heap")]
     for i in 0..300 {
